[Cmake-commits] CMake branch, next, updated. v2.8.6-1716-g0cf5ea3

2011-10-30 Thread Eric Noulard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  0cf5ea351006f7bdb905b7610ab6946b9da3f174 (commit)
   via  e20c59ae5013affa5f80f5f9b76020bdcbd42f4d (commit)
   via  ba5c6493d9a2ae1a24df725136395c36850de6f2 (commit)
   via  6a6f21412db4b34fdcc4ad4021ec12fa273b7aad (commit)
   via  9a6257a40b8c915cf61d2d4e7f1f5a2e4b7b310a (commit)
  from  314e67e8236ce4d16c2865b0fe71d412f9792627 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0cf5ea351006f7bdb905b7610ab6946b9da3f174
commit 0cf5ea351006f7bdb905b7610ab6946b9da3f174
Merge: 314e67e e20c59a
Author: Eric Noulard eric.noul...@gmail.com
AuthorDate: Sun Oct 30 15:16:07 2011 -0400
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Sun Oct 30 15:16:07 2011 -0400

Merge topic 'CPackRPM-perComponentHeader' into next

e20c59a CPackRPM support component specific variables for spec files
ba5c649 KWSys Nightly Date Stamp
6a6f214 KWSys Nightly Date Stamp
9a6257a KWSys Nightly Date Stamp


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=e20c59ae5013affa5f80f5f9b76020bdcbd42f4d
commit e20c59ae5013affa5f80f5f9b76020bdcbd42f4d
Author: Eric NOULARD eric.noul...@gmail.com
AuthorDate: Sun Oct 30 20:13:20 2011 +0100
Commit: Eric NOULARD eric.noul...@gmail.com
CommitDate: Sun Oct 30 20:13:20 2011 +0100

CPackRPM support component specific variables for spec files

This is a modified version of a user patch
Inspired-By: informant

diff --git a/Source/cmDocumentVariables.cxx b/Source/cmDocumentVariables.cxx
index f4d4e7c..f46e1ce 100644
--- a/Source/cmDocumentVariables.cxx
+++ b/Source/cmDocumentVariables.cxx
@@ -126,7 +126,7 @@ void cmDocumentVariables::DefineVariables(cmake* cm)
  This variable is set to the program that will be
   needed to build the output of CMake.   If the 
  generator selected was Visual Studio 6, the 
- CMAKE_MAKE_PROGRAM will be set to msdev, for 
+ CMAKE_BUILD_TOOL will be set to msdev, for 
  Unix makefiles it will be set to make or gmake, 
  and for Visual Studio 7 it set to devenv.  For 
  Nmake Makefiles the value is nmake. This can be 

---

Summary of changes:
 Source/cmDocumentVariables.cxx|2 +-
 Source/kwsys/kwsysDateStamp.cmake |2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)


hooks/post-receive
diff --git a/Modules/CPackRPM.cmake b/Modules/CPackRPM.cmake
index 51c8eac..36b86cf 100644
--- a/Modules/CPackRPM.cmake
+++ b/Modules/CPackRPM.cmake
@@ -4,7 +4,10 @@
 # used by CPack : http://www.cmake.org/Wiki/CMake:CPackConfiguration
 #
 # However CPackRPM has specific features which are controlled by
-# the specifics CPACK_RPM_XXX variables.
+# the specifics CPACK_RPM_XXX variables. CPackRPM is a component aware
+# generator so when CPACK_RPM_COMPONENT_INSTALL is ON some more
+# CPACK_RPM_ComponentName_ variables may be used in order
+# to have component specific values.
 # Usually those vars correspond to RPM spec file entities, one may find
 # information about spec files here http://www.rpm.org/wiki/Docs.
 # You'll find a detailed usage of CPackRPM on the wiki:
@@ -388,9 +391,33 @@ if(CPACK_RPM_PACKAGE_RELOCATABLE)
   endif(CPACK_SET_DESTDIR AND (NOT CPACK_SET_DESTDIR STREQUAL I_ON))
 endif(CPACK_RPM_PACKAGE_RELOCATABLE)
 
 # check if additional fields for RPM spec header are given
 FOREACH(_RPM_SPEC_HEADER URL REQUIRES SUGGESTS PROVIDES OBSOLETES PREFIX 
CONFLICTS AUTOPROV AUTOREQ AUTOREQPROV)
-  IF(CPACK_RPM_PACKAGE_${_RPM_SPEC_HEADER})
+IF(CPACK_RPM_PACKAGE_DEBUG)
+  message(CPackRPM:Debug: processing ${_RPM_SPEC_HEADER})
+ENDIF(CPACK_RPM_PACKAGE_DEBUG)
+if(CPACK_RPM_PACKAGE_COMPONENT)
+
if(CPACK_RPM_${CPACK_RPM_PACKAGE_COMPONENT}_PACKAGE_${_RPM_SPEC_HEADER})
+IF(CPACK_RPM_PACKAGE_DEBUG)
+  message(CPackRPM:Debug: using 
CPACK_RPM_${CPACK_RPM_PACKAGE_COMPONENT}_PACKAGE_${_RPM_SPEC_HEADER})
+ENDIF(CPACK_RPM_PACKAGE_DEBUG)
+set(CPACK_RPM_PACKAGE_${_RPM_SPEC_HEADER}_TMP 
${CPACK_RPM_${CPACK_RPM_PACKAGE_COMPONENT}_PACKAGE_${_RPM_SPEC_HEADER}})
+else()
+IF(CPACK_RPM_PACKAGE_DEBUG)
+  message(CPackRPM:Debug: 
CPACK_RPM_${CPACK_RPM_PACKAGE_COMPONENT}_PACKAGE_${_RPM_SPEC_HEADER} not 
defined)
+  message(CPackRPM:Debug: using 
CPACK_RPM_PACKAGE_${_RPM_SPEC_HEADER})
+ENDIF(CPACK_RPM_PACKAGE_DEBUG)
+set(CPACK_RPM_PACKAGE_${_RPM_SPEC_HEADER}_TMP 
${CPACK_RPM_PACKAGE_${_RPM_SPEC_HEADER}})
+endif()
+else()
+IF(CPACK_RPM_PACKAGE_DEBUG)
+  message(CPackRPM:Debug: using 
CPACK_RPM_PACKAGE_${_RPM_SPEC_HEADER})
+ENDIF(CPACK_RPM_PACKAGE_DEBUG)
+set(CPACK_RPM_PACKAGE_${_RPM_SPEC_HEADER}_TMP 
${CPACK_RPM_PACKAGE_${_RPM_SPEC_HEADER}})
+endif()
+
+  IF(CPACK_RPM_PACKAGE_${_RPM_SPEC_HEADER}_TMP)
 STRING(LENGTH ${_RPM_SPEC_HEADER} _PACKAGE_HEADER_STRLENGTH)
 MATH(EXPR _PACKAGE_HEADER_STRLENGTH ${_PACKAGE_HEADER_STRLENGTH} - 1)
 STRING(SUBSTRING ${_RPM_SPEC_HEADER} 1 ${_PACKAGE_HEADER_STRLENGTH} 
_PACKAGE_HEADER_TAIL)
@@ -398,10 +425,10 @@ FOREACH(_RPM_SPEC_HEADER URL REQUIRES SUGGESTS PROVIDES 
OBSOLETES PREFIX CONFLIC
 STRING(SUBSTRING ${_RPM_SPEC_HEADER} 0 1 _PACKAGE_HEADER_NAME)
 SET(_PACKAGE_HEADER_NAME ${_PACKAGE_HEADER_NAME}${_PACKAGE_HEADER_TAIL})
 

[Cmake-commits] CMake branch, next, updated. v2.8.6-1719-g4f2b452

2011-10-30 Thread Eric Noulard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  4f2b45203247a27c91f5d16f591cc4491a6ad0d4 (commit)
   via  83b13a250c33bea56eadc7a9cf9f3c55546b (commit)
   via  b1e9e55c6c56a07a7d8f4380bc5c16a1722e52ca (commit)
  from  0cf5ea351006f7bdb905b7610ab6946b9da3f174 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
@@ -388,9 +391,33 @@ if(CPACK_RPM_PACKAGE_RELOCATABLE)
 endif(CPACK_RPM_PACKAGE_RELOCATABLE)
 
-# check if additional fields for RPM spec header are given
+# Check if additional fields for RPM spec header are given
+# There may be some COMPONENT specific variables as well
 FOREACH(_RPM_SPEC_HEADER URL REQUIRES SUGGESTS PROVIDES OBSOLETES PREFIX 
CONFLICTS AUTOPROV AUTOREQ AUTOREQPROV)
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=4f2b45203247a27c91f5d16f591cc4491a6ad0d4
commit 4f2b45203247a27c91f5d16f591cc4491a6ad0d4
Merge: 0cf5ea3 83b13a2
Author: Eric Noulard eric.noul...@gmail.com
AuthorDate: Sun Oct 30 17:36:41 2011 -0400
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Sun Oct 30 17:36:41 2011 -0400

Merge topic 'FixCMAKE_BUILD_TOOL_doc' into next

83b13a2 Fix old reference to CMAKE_MAKE_PROGRAM inside CMAKE_BUILD_TOOL doc.
b1e9e55 KWSys Nightly Date Stamp


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=83b13a250c33bea56eadc7a9cf9f3c55546b
commit 83b13a250c33bea56eadc7a9cf9f3c55546b
Author: Eric NOULARD eric.noul...@gmail.com
AuthorDate: Sun Oct 30 22:34:18 2011 +0100
Commit: Eric NOULARD eric.noul...@gmail.com
CommitDate: Sun Oct 30 22:34:18 2011 +0100

Fix old reference to CMAKE_MAKE_PROGRAM inside CMAKE_BUILD_TOOL doc.

-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits